cmd

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: MIT Imports: 31 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "dev"

Version is the current CLI version, set via SetVersion at startup.

Functions

func Execute

func Execute(fsys fs.FS, guides map[string]string)

Execute is the main entry point for the CLI.

func SetVersion

func SetVersion(v string)

SetVersion sets the version string on the root command.

Types

This section is empty.

Directories

Path Synopsis

Jump to